@@ -1,7 +1,9 @@
 from libcomxml.core import XmlModel, XmlField
 from primestg.order.base import (OrderHeader, CntOrderHeader)
-from primestg.utils import ContractTemplates, DLMSTemplates, datetimetoprime, name2octet
+from primestg.utils import ContractTemplates, DLMSTemplates, datetimetoprime, name2octet, datetohexprime
 from pytz import timezone
+from datetime import datetime
+from dateutil.relativedelta import relativedelta
 
 
 TZ = timezone('Europe/Madrid')
@@ -423,13 +425,27 @@ class B12Payload(XmlModel):
                 'Ffin': payload.get('date_to'),
             })
         tmpl_name = payload.get('template', 'TAR_20TD')
+        powers = payload.get('powers', ['15000', '15000', '15000', '15000', '15000', '15000'])
+        latent_date = payload.get('date', (datetime.today() + relativedelta(days=1)).date())
+
+
+        params = {}
+        hex_powers = dict(zip(['p1', 'p2', 'p3', 'p4', 'p5', 'p6'], powers))
+        for period, power in hex_powers.items():
+            hexnumber = '{0:08x}'.format(int(power))
+            hex_powers[period] = ''.join([hexnumber[i:i + 2] for i in range(0, 8, 2)])
+        params.update(hex_powers)
+        params.update({'date': datetohexprime(latent_date)})
+
         dt = DLMSTemplates()
         template = dt.get_template(tmpl_name)
 
         data = template['data']
         sets = []
-        for set in data:
-            sets.append(Set(set))
+        for set_line in data:
+            new_set = set_line.copy()
+            new_set['data'] = set_line['data'].format(**params)
+            sets.append(Set(new_set))
         self.sets = sets
 
         super(B12Payload, self).__init__('b12Payload', 'payload', drop_empty=drop_empty)
