@@ -1,5 +1,7 @@
 from datetime import datetime
 import binascii
+import re
+from primestg.utils import octet2date
 
 
 MAGNITUDE_W = 1
@@ -61,10 +63,12 @@ class ValueWithTime(object):
             date_value = '19000101000000W'
 
         if date_value.upper().startswith('FFFF'):
-            date_value = '9999{}'.format(date_value[:4])
-
+            date_value = '9999' + date_value[4:]
         try:
-            time = datetime.strptime(date_value[:-1], '%Y%m%d%H%M%S')
+            if re.search('[A-F]', date_value[0:4]):
+                time = octet2date(date_value)
+            else:
+                time = datetime.strptime(date_value[:-1], '%Y%m%d%H%M%S')
         except ValueError as e:
             raise ValueError("Date out of range: {} ({}) {}".format(
                 date_value, name, e))
